<a href="https://github.com/DLu/googly/" style="float: right">
<figure style="border: 1px solid black; text-align: center; width: 200px">
  <img src="https://github.githubassets.com/assets/GitHub-Mark-ea2971cee799.png" alt="octocat" style="height:150px;"/>
  <figcaption><i>source repo</i></figcaption>
</figure>
</a>

# ![googly](_static/logo.gif)

```{include} ../../README.md
:start-after: <!-- SPHINX-START -->
:end-before: <!-- SPHINX-STOP -->
```

## Guides
```{toctree}
:maxdepth: 2

google
googly
auth
apps
links
```


## Indices and tables

- {ref}`genindex`
- {ref}`search`

![a buncha googly eyes](https://media3.giphy.com/media/v1.Y2lkPTc5MGI3NjExdWVsaWZ1cDZ0dzY2ZHlkdGJib2hieTdmeHp2azE3ZnlwYWhoOTlsMiZlcD12MV9pbnRlcm5hbF9naWZfYnlfaWQmY3Q9Zw/FkLMzWnIHxcs9WDJvf/giphy.gif)
